@@ -29,7 +29,9 @@ __all__ = (
     "ListTargetsPaginatorName",
     "NotificationRuleStatusType",
     "TargetStatusType",
+    "CodeStarNotificationsServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -45,6 +47,7 @@ ListTargetsFilterNameType = Literal["TARGET_ADDRESS", "TARGET_STATUS", "TARGET_T
 ListTargetsPaginatorName = Literal["list_targets"]
 NotificationRuleStatusType = Literal["DISABLED", "ENABLED"]
 TargetStatusType = Literal["ACTIVE", "DEACTIVATED", "INACTIVE", "PENDING", "UNREACHABLE"]
+CodeStarNotificationsServiceName = Literal["codestar-notifications"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -76,6 +79,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -198,6 +202,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -346,4 +351,16 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_event_types", "list_notification_rules", "list_targets"]
