@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     DetailTypeType,
     ListEventTypesFilterNameType,
@@ -65,33 +67,19 @@ __all__ = (
     "UpdateNotificationRuleRequestRequestTypeDef",
 )
 
-_RequiredCreateNotificationRuleRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateNotificationRuleRequestRequestTypeDef",
+CreateNotificationRuleRequestRequestTypeDef = TypedDict(
+    "CreateNotificationRuleRequestRequestTypeDef",
     {
         "Name": str,
         "EventTypeIds": Sequence[str],
         "Resource": str,
         "Targets": Sequence["TargetTypeDef"],
         "DetailType": DetailTypeType,
+        "ClientRequestToken": NotRequired[str],
+        "Tags": NotRequired[Mapping[str, str]],
+        "Status": NotRequired[NotificationRuleStatusType],
     },
 )
-_OptionalCreateNotificationRuleRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateNotificationRuleRequestRequestTypeDef",
-    {
-        "ClientRequestToken": str,
-        "Tags": Mapping[str, str],
-        "Status": NotificationRuleStatusType,
-    },
-    total=False,
-)
-
-
-class CreateNotificationRuleRequestRequestTypeDef(
-    _RequiredCreateNotificationRuleRequestRequestTypeDef,
-    _OptionalCreateNotificationRuleRequestRequestTypeDef,
-):
-    pass
-
 
 CreateNotificationRuleResultTypeDef = TypedDict(
     "CreateNotificationRuleResultTypeDef",
@@ -116,26 +104,13 @@ DeleteNotificationRuleResultTypeDef = TypedDict(
     },
 )
 
-_RequiredDeleteTargetRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteTargetRequestRequestTypeDef",
+DeleteTargetRequestRequestTypeDef = TypedDict(
+    "DeleteTargetRequestRequestTypeDef",
     {
         "TargetAddress": str,
+        "ForceUnsubscribeAll": NotRequired[bool],
     },
 )
-_OptionalDeleteTargetRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteTargetRequestRequestTypeDef",
-    {
-        "ForceUnsubscribeAll": bool,
-    },
-    total=False,
-)
-
-
-class DeleteTargetRequestRequestTypeDef(
-    _RequiredDeleteTargetRequestRequestTypeDef, _OptionalDeleteTargetRequestRequestTypeDef
-):
-    pass
-
 
 DescribeNotificationRuleRequestRequestTypeDef = TypedDict(
     "DescribeNotificationRuleRequestRequestTypeDef",
@@ -165,12 +140,11 @@ DescribeNotificationRuleResultTypeDef = TypedDict(
 EventTypeSummaryTypeDef = TypedDict(
     "EventTypeSummaryTypeDef",
     {
-        "EventTypeId": str,
-        "ServiceName": str,
-        "EventTypeName": str,
-        "ResourceType": str,
+        "EventTypeId": NotRequired[str],
+        "ServiceName": NotRequired[str],
+        "EventTypeName": NotRequired[str],
+        "ResourceType": NotRequired[str],
     },
-    total=False,
 )
 
 ListEventTypesFilterTypeDef = TypedDict(
@@ -184,11 +158,10 @@ ListEventTypesFilterTypeDef = TypedDict(
 ListEventTypesRequestRequestTypeDef = TypedDict(
     "ListEventTypesRequestRequestTypeDef",
     {
-        "Filters": Sequence["ListEventTypesFilterTypeDef"],
-        "NextToken": str,
-        "MaxResults": int,
+        "Filters": NotRequired[Sequence["ListEventTypesFilterTypeDef"]],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListEventTypesResultTypeDef = TypedDict(
@@ -211,11 +184,10 @@ ListNotificationRulesFilterTypeDef = TypedDict(
 ListNotificationRulesRequestRequestTypeDef = TypedDict(
     "ListNotificationRulesRequestRequestTypeDef",
     {
-        "Filters": Sequence["ListNotificationRulesFilterTypeDef"],
-        "NextToken": str,
-        "MaxResults": int,
+        "Filters": NotRequired[Sequence["ListNotificationRulesFilterTypeDef"]],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListNotificationRulesResultTypeDef = TypedDict(
@@ -253,11 +225,10 @@ ListTargetsFilterTypeDef = TypedDict(
 ListTargetsRequestRequestTypeDef = TypedDict(
     "ListTargetsRequestRequestTypeDef",
     {
-        "Filters": Sequence["ListTargetsFilterTypeDef"],
-        "NextToken": str,
-        "MaxResults": int,
+        "Filters": NotRequired[Sequence["ListTargetsFilterTypeDef"]],
+        "NextToken": NotRequired[str],
+        "MaxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListTargetsResultTypeDef = TypedDict(
@@ -272,20 +243,18 @@ ListTargetsResultTypeDef = TypedDict(
 NotificationRuleSummaryTypeDef = TypedDict(
     "NotificationRuleSummaryTypeDef",
     {
-        "Id": str,
-        "Arn": str,
+        "Id": NotRequired[str],
+        "Arn": NotRequired[str],
     },
-    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -299,27 +268,14 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredSubscribeRequestRequestTypeDef = TypedDict(
-    "_RequiredSubscribeRequestRequestTypeDef",
+SubscribeRequestRequestTypeDef = TypedDict(
+    "SubscribeRequestRequestTypeDef",
     {
         "Arn": str,
         "Target": "TargetTypeDef",
+        "ClientRequestToken": NotRequired[str],
     },
 )
-_OptionalSubscribeRequestRequestTypeDef = TypedDict(
-    "_OptionalSubscribeRequestRequestTypeDef",
-    {
-        "ClientRequestToken": str,
-    },
-    total=False,
-)
-
-
-class SubscribeRequestRequestTypeDef(
-    _RequiredSubscribeRequestRequestTypeDef, _OptionalSubscribeRequestRequestTypeDef
-):
-    pass
-
 
 SubscribeResultTypeDef = TypedDict(
     "SubscribeResultTypeDef",
@@ -348,20 +304,18 @@ TagResourceResultTypeDef = TypedDict(
 TargetSummaryTypeDef = TypedDict(
     "TargetSummaryTypeDef",
     {
-        "TargetAddress": str,
-        "TargetType": str,
-        "TargetStatus": TargetStatusType,
+        "TargetAddress": NotRequired[str],
+        "TargetType": NotRequired[str],
+        "TargetStatus": NotRequired[TargetStatusType],
     },
-    total=False,
 )
 
 TargetTypeDef = TypedDict(
     "TargetTypeDef",
     {
-        "TargetType": str,
-        "TargetAddress": str,
+        "TargetType": NotRequired[str],
+        "TargetAddress": NotRequired[str],
     },
-    total=False,
 )
 
 UnsubscribeRequestRequestTypeDef = TypedDict(
@@ -388,27 +342,14 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateNotificationRuleRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateNotificationRuleRequestRequestTypeDef",
+UpdateNotificationRuleRequestRequestTypeDef = TypedDict(
+    "UpdateNotificationRuleRequestRequestTypeDef",
     {
         "Arn": str,
+        "Name": NotRequired[str],
+        "Status": NotRequired[NotificationRuleStatusType],
+        "EventTypeIds": NotRequired[Sequence[str]],
+        "Targets": NotRequired[Sequence["TargetTypeDef"]],
+        "DetailType": NotRequired[DetailTypeType],
     },
 )
-_OptionalUpdateNotificationRuleRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateNotificationRuleRequestRequestTypeDef",
-    {
-        "Name": str,
-        "Status": NotificationRuleStatusType,
-        "EventTypeIds": Sequence[str],
-        "Targets": Sequence["TargetTypeDef"],
-        "DetailType": DetailTypeType,
-    },
-    total=False,
-)
-
-
-class UpdateNotificationRuleRequestRequestTypeDef(
-    _RequiredUpdateNotificationRuleRequestRequestTypeDef,
-    _OptionalUpdateNotificationRuleRequestRequestTypeDef,
-):
-    pass
